@@ -102,7 +102,7 @@ static gboolean		mapi_folder_synchronize_sync
 						 GCancellable *cancellable,
 						 GError **error);
 
-G_DEFINE_TYPE (CamelMapiFolder, camel_mapi_folder, CAMEL_TYPE_OFFLINE_FOLDER)
+G_DEFINE_TYPE_WITH_PRIVATE (CamelMapiFolder, camel_mapi_folder, CAMEL_TYPE_OFFLINE_FOLDER)
 
 static GPtrArray *
 mapi_folder_search_by_expression (CamelFolder *folder,
@@ -183,7 +183,7 @@ mapi_set_message_references (CamelMessageInfo *mi,
 	refs = camel_header_references_decode (references);
 	irt = camel_header_references_decode (in_reply_to);
 	if (refs || irt) {
-		GArray *references;
+		GArray *references_arr;
 
 		if (irt) {
 			/* The References field is populated from the "References" and/or "In-Reply-To"
@@ -193,7 +193,7 @@ mapi_set_message_references (CamelMessageInfo *mi,
 			refs = g_slist_concat (irt, refs);
 		}
 
-		references = g_array_sized_new (FALSE, FALSE, sizeof (guint64), g_slist_length (refs));
+		references_arr = g_array_sized_new (FALSE, FALSE, sizeof (guint64), g_slist_length (refs));
 
 		length = g_checksum_type_get_length (G_CHECKSUM_MD5);
 		digest = g_alloca (length);
@@ -208,12 +208,12 @@ mapi_set_message_references (CamelMessageInfo *mi,
 
 			memcpy (tmp_msgid.id.hash, digest, sizeof (tmp_msgid.id.hash));
 
-			g_array_append_val (references, tmp_msgid.id.id);
+			g_array_append_val (references_arr, tmp_msgid.id.id);
 		}
 
 		g_slist_free_full (refs, g_free);
 
-		camel_message_info_take_references (mi, references);
+		camel_message_info_take_references (mi, references_arr);
 	}
 }
 
@@ -1958,8 +1958,6 @@ camel_mapi_folder_class_init (CamelMapiFolderClass *class)
 	GObjectClass *object_class;
 	CamelFolderClass *folder_class;
 
-	g_type_class_add_private (class, sizeof (CamelMapiFolderPrivate));
-
 	object_class = G_OBJECT_CLASS (class);
 	object_class->dispose = mapi_folder_dispose;
 	object_class->finalize = mapi_folder_finalize;
@@ -1987,7 +1985,7 @@ camel_mapi_folder_init (CamelMapiFolder *mapi_folder)
 {
 	CamelFolder *folder = CAMEL_FOLDER (mapi_folder);
 
-	mapi_folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (mapi_folder, CAMEL_TYPE_MAPI_FOLDER, CamelMapiFolderPrivate);
+	mapi_folder->priv = camel_mapi_folder_get_instance_private (mapi_folder);
 
 	camel_folder_set_flags (folder, CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY);
 
