@@ -269,7 +269,7 @@ edit_permissions_response_cb (GObject *dialog,
 	}
 
 	e_mapi_config_utils_run_in_thread_with_feedback (GTK_WINDOW (dialog), dialog,
-		_("Writing folder permissions, please wait..."),
+		_("Writing folder permissions, please wait…"),
 		write_folder_permissions_thread,
 		write_folder_permissions_idle,
 		write_entries, (GDestroyNotify) g_slist_free);
@@ -863,6 +863,7 @@ create_permissions_tree_view (GObject *dialog,
 			      struct EMapiPermissionsDialogWidgets *widgets)
 {
 	GtkTreeView *tree_view;
+	GtkTreeModel *model;
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -870,8 +871,9 @@ create_permissions_tree_view (GObject *dialog,
 
 	g_return_val_if_fail (widgets != NULL, NULL);
 
-	tree_view = GTK_TREE_VIEW (gtk_tree_view_new_with_model (
-		GTK_TREE_MODEL (gtk_list_store_new (5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_BOOLEAN))));
+	model = GTK_TREE_MODEL (gtk_list_store_new (5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_BOOLEAN));
+	tree_view = GTK_TREE_VIEW (gtk_tree_view_new_with_model (model));
+	g_object_unref (model);
 
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "editable", FALSE, NULL);
@@ -934,7 +936,7 @@ e_mapi_edit_folder_permissions (GtkWindow *parent,
 	widgets->foreign_username = g_strdup (foreign_username);
 
 	widgets->dialog = gtk_dialog_new_with_buttons (
-		_("Edit MAPI folder permissions..."),
+		_("Edit MAPI folder permissions…"),
 		parent,
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1278,7 +1280,7 @@ e_mapi_edit_folder_permissions (GtkWindow *parent,
 	found_entries = g_new0 (GSList *, 1);
 
 	e_mapi_config_utils_run_in_thread_with_feedback (GTK_WINDOW (dialog), dialog,
-		_("Reading folder permissions, please wait..."),
+		_("Reading folder permissions, please wait…"),
 		read_folder_permissions_thread,
 		read_folder_permissions_idle,
 		found_entries, folder_permissions_free_found_entries);
